summaryrefslogtreecommitdiff
path: root/Build/tools/MakeImages.sh
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2006-02-14 00:54:57 +0000
committerKarl Berry <karl@freefriends.org>2006-02-14 00:54:57 +0000
commit2e833c685a007ffd7649dec30fd6a3a75769b242 (patch)
tree8c733cddbba19deddae23a24f36cf231fef80dc2 /Build/tools/MakeImages.sh
parent2eba0ce0cddb0d290614b2bd6ea0cd6718ac5b54 (diff)
find tools under Build, remove old scripts
git-svn-id: svn://tug.org/texlive/trunk@1518 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build/tools/MakeImages.sh')
-rwxr-xr-xBuild/tools/MakeImages.sh22
1 files changed, 10 insertions, 12 deletions
diff --git a/Build/tools/MakeImages.sh b/Build/tools/MakeImages.sh
index bcc9f5b8854..d9910514b44 100755
--- a/Build/tools/MakeImages.sh
+++ b/Build/tools/MakeImages.sh
@@ -32,7 +32,7 @@ umask 0
HERE=`cd \`dirname $0\` && /bin/pwd`
cd $HERE || exit 1 # the Tools directory
-source=`cd .. && /bin/pwd`
+master=`cd ../../Master && /bin/pwd`
NAME=texlivetest
V=2006
@@ -53,7 +53,7 @@ while test $# -gt 0; do
--noinst) makeinst=false;;
--nolive) makelive=false;;
--quiet) quiet=-quiet;;
- --source=*) source=`echo $1 | sed 's/.*=//'`;;
+ --source=*) master=`echo $1 | sed 's/.*=//'`;;
--work=*) work=`echo $1 | sed 's/.*=//'`;;
--target=*) target=`echo $1 | sed 's/.*=//'`;;
--zippath=*) zippath=`echo $1 | sed 's/.*=//'`;;
@@ -63,7 +63,7 @@ while test $# -gt 0; do
done
if $debug; then
- echo "source = $source"
+ echo "master = $master"
echo "target = $target"
echo "work = $work"
fi
@@ -74,7 +74,6 @@ common_mkisofs_options=" $quiet -pad -J -dir-mode 0755 -r \
-x install-live.sh -x install-compr.sh \
-x install-pkg-compr.sh -x install-pkg-live.sh \
-x ./support/tests \
- -x Tools \
-x .svn \
"
@@ -83,8 +82,8 @@ MAKELIVE () {
live_iso=$target/$NAME$V-live-$D.iso
echo "--- `date` Writing complete live image to $live_iso."
-# Basically copy the source directory.
-(cd $source || exit 1
+# Basically copy the master directory.
+(cd $master || exit 1
# Complication: get the right install-tl.sh.
rm -f install-tl.sh install-pkg.sh
cp -p install-live.sh install-tl.sh
@@ -125,7 +124,7 @@ test -d $WORK && rm -rf $WORK
mkdir -p $WORK
$debug && echo Copy top-level files
-cd $source
+cd $master || exit 1
tar cf - \
support \
.mkisofsrc config.* autorun.inf \
@@ -136,7 +135,6 @@ tar cf - \
setup-win32/help/* \
setup-win32/msgs/* \
setup-win32/* \
- Tools \
source \
texmf-doc/doc/*/texlive-* \
00INST.TL *html \
@@ -144,12 +142,12 @@ tar cf - \
# initial texmf-var
mkdir $WORK/texmf-var
-cd $source/texmf-dist || exit 1
+cd $master/texmf-dist || exit 1
tar cf - \
tex/plain/config/language.def \
tex/context/config/cont-usr.tex \
| (cd $WORK/texmf-var; tar xf - )
-cd $source/texmf || exit 1
+cd $master/texmf || exit 1
# updmap.cfg gets generated at install time, we don't want to copy the
# one from the distribution.
tar cf - \
@@ -171,7 +169,7 @@ cd $WORK && rm -rf texmf-var
$debug && echo Prepare zip files...
PATH=$PATH:$zippath
export PATH
-cd $source || exit 1
+cd $master || exit 1
# people want to get the windows binaries, so don't exclude everything.
# bzip2, perl, windvi, lib-* -- basically required.
# Fabrice suggests dumping the below, but since we seem to have room for
@@ -190,7 +188,7 @@ for i in texmf/lists/*; do
done
# copy tpm directories
-cd $source
+cd $master || exit 1
tar cf - texmf/lists texmf/tpm texmf-dist/tpm texmf-doc/tpm \
| (cd $WORK; tar xf - )